@@ -3,7 +3,8 @@
 #' and polishes the labels ready for used in mapping with \code{merge_with_geodata} function and ggplot2.
 #' @param x A numeric vector, eg. \code{values} variable in data returned by  \code{get_eurostat}
 #' @param n A numeric. number of classes/categories
-#' @param style Chosen style: one of "fixed", "sd", "equal", "pretty", "quantile", "kmeans", "hclust", "bclust", "fisher", or "jenks"
+#' @param style Chosen style: one of "fixed", "sd", "equal", "pretty", "quantile", "kmeans", "hclust",
+#' "bclust", "fisher", or "jenks"
 #' @param manual Logical. If manual breaks are being used
 #' @param manual_breaks Numeric vector with manual threshold values
 #' @param decimals Number of decimals to include with labels
@@ -14,10 +15,19 @@
 #' @examples
 #'  \dontrun{
 #'    lp <- get_eurostat("nama_aux_lp")
-#'    lp$class <- cut_to_classes(lp$values, n=5, style="jenks",decimals=1)
+#'    lp$class <- cut_to_classes(lp$values, n=5, style="equal", decimals=1)
 #'  }
-cut_to_classes <- function(x, n=5,style="jenks",manual=FALSE,manual_breaks = NULL,decimals=0,nodata_label="No data") {
-  
+cut_to_classes <- function(x, n=5, style="equal", manual=FALSE, 
+                           manual_breaks = NULL, decimals=0, 
+                           nodata_label="No data") {
+
+  manual_breaks_orig <- manual_breaks
+  if (!is.null(manual_breaks) && (length(unique(manual_breaks)) == length(manual_breaks))) {
+    warning("manual_breaks in cut_to_classes are not unique. Using unique breaks only.")
+    manual_breaks <- unique(manual_breaks)
+    
+  }
+
   if (manual) {
     levs <- as.data.frame(levels(cut(x, 
                                      breaks=manual_breaks,
@@ -27,6 +37,9 @@ cut_to_classes <- function(x, n=5,style="jenks",manual=FALSE,manual_breaks = NUL
 
     brs <- data.frame(classInt::classIntervals(x,n=n,style=style)[2])[,1]
 
+    # Ensure that the breaks are unique
+    brs <- unique(brs)
+
     cutting <- cut(x, breaks=brs, include.lowest=T, dig.lab=5)
 
     levs <- levels(cutting)
@@ -60,7 +73,12 @@ cut_to_classes <- function(x, n=5,style="jenks",manual=FALSE,manual_breaks = NUL
              dig.lab=5, labels = labs)
     rm(manual_breaks)
   } else {
-    y <- cut(x, breaks = data.frame(classIntervals(x,n = n, style = style)[2])[,1],
+    brs2 <- data.frame(classIntervals(x,n = n, style = style)[2])[,1]
+
+    # Ensure the breaks are unique
+    brs2 <- unique(brs2)
+
+    y <- cut(x, breaks = brs2,
              include.lowest=T,
              dig.lab=5, labels = labs)
   }
